/*
 *  Copyright (c) Members of the EGEE Collaboration. 2005.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Management - Simple data delegation API
 *
 *  Authors: Zoltan Farkas <Zoltan.Farkas@cern.ch>
 *
 */

#ifndef GLITE_DATA_DELEGATION_H
#define GLITE_DATA_DELEGATION_H

#ifdef __cplusplus
extern "C" {
#endif

/**********************************************************************
 * Constants
 */

/* Service type for Service Discovery */
#define GLITE_DELEGATION_SD_TYPE       "org.glite.Delegation"

/* Environment variable to override service type */
#define GLITE_DELEGATION_SD_ENV        "GLITE_SD_DELEGATION_TYPE"


/**********************************************************************
 * Function prototypes - library management functions
 */

char *glite_delegation_get_error();

/**
 * Do the delegation work.
 *
 * @param endpoint Server URL to connect to.
 * @param delegationID The id used to identify the delegation process and the
 *                     resulting delegated credentials in the server.
 * @param expiration Expritation time.
 *
 * @return 0 if OK, -1 in case of error
 */
int glite_delegation_dowork(const char *endpoint, const char *delegationID,
    int expiration);

/**
 * @}
 */

#ifdef __cplusplus
}
#endif

#endif /* GLITE_DATA_SECURITY_DELEGATION_H */
